Citing discretize
-----------------

There is a `paper about discretize <http://dx.doi.org/10.1016/j.cageo.2015.09.015>`_ as it is used in SimPEG,
if you use this code, please help our scientific visibility by citing our work!


    Cockett, R., Kang, S., Heagy, L. J., Pidlisecky, A., & Oldenburg, D. W. (2015). SimPEG: An open source framework for simulation and gradient based parameter estimation in geophysical applications. Computers & Geosciences.


BibTex:

.. code:: Latex

    @article{Cockett2015,
      title={SimPEG: An open source framework for simulation and gradient based parameter estimation in geophysical applications},
      author={Cockett, Rowan and Kang, Seogi and Heagy, Lindsey J and Pidlisecky, Adam and Oldenburg, Douglas W},
      journal={Computers \& Geosciences},
      year={2015},
      publisher={Elsevier}
    }

